@@ -219,7 +219,7 @@ xfpm_battery_get_message_from_battery_state (XfpmBattery *battery)
 		    
 		    est_time_str = xfpm_battery_get_time_string (battery->priv->time_to_full);
 		    
-		    msg = g_strdup_printf ("%s (%i%%)\n%s until is fully charged.", tmp, battery->priv->percentage, est_time_str);
+		    msg = g_strdup_printf (_("%s (%i%%)\n%s until is fully charged."), tmp, battery->priv->percentage, est_time_str);
 		    g_free (est_time_str);
 		    g_free (tmp);
 		}
@@ -239,7 +239,7 @@ xfpm_battery_get_message_from_battery_state (XfpmBattery *battery)
 			
 			est_time_str = xfpm_battery_get_time_string (battery->priv->time_to_empty);
 			
-			msg = g_strdup_printf ("%s (%i%%)\nEstimated time left is %s.", tmp, battery->priv->percentage, est_time_str);
+			msg = g_strdup_printf (_("%s (%i%%)\nEstimated time left is %s."), tmp, battery->priv->percentage, est_time_str);
 			g_free (tmp);
 			g_free (est_time_str);
 		    }
@@ -309,10 +309,14 @@ xfpm_battery_refresh_icon (XfpmBattery *battery)
 			battery->priv->icon_prefix, 
 			xfpm_battery_get_icon_index (battery->priv->type, battery->priv->percentage));
 	}
+	else if ( battery->priv->state == XFPM_DEVICE_STATE_EMPTY)
+	{
+	    g_snprintf (icon_name, 128, "%s%s", battery->priv->icon_prefix, battery->priv->ac_online ? "000-charging" : "000");
+	}
     }
     else
     {
-	if ( !battery->priv->present )
+	if ( !battery->priv->present || battery->priv->state == XFPM_DEVICE_STATE_EMPTY )
 	{
 	    g_snprintf (icon_name, 128, "%s-000", battery->priv->icon_prefix);
 	}
